const path = require('path');
const child_process = require("child_process");
const fs = require("fs");
const mist = require('minimist');
const {Branch,build}= require("./layer")
const {creat_id} = require("nv-facutil-basic");
const Forest  = require("nv-data-tree-csp-forest");


function creat_argv() {
    let argv = mist(
        process.argv.slice(2),
        {
            alias: {
                'help':'h',
                'maxsize':'m',
                'before':'b',
                'after':'a',
                'children':'c',
                'position':'p',
                'number':'n',
                'remove':'r',
                'input' :'i',
            },
            boolean:['before','after','children','remove'],
            default: {
                'maxsize':10000,
                'number':1,
                'position':0
            }
        }
    );
    return(argv)
}


function usage () {
    console.log(
        `
  Usage: nv_if_layer  [options] 
  Options:
    -i, --input                       tmp filename 
    -p, --position                    position,number in /*<index>*/
    -c, --children                    insert as children
    -a, --after                       insert after
    -b, --before                      insert before
    -n, --number                      insert how many,default 1
    -r, --remove                      remove 
    -m, --maxsize                     the max-supported nodes,default 10000
    -h, --help                        Output usage information`
    )
   console.log("\n");
}


function run() {
    let argv = creat_argv();
    console.log(argv)
    if (argv.help) {
        usage();
    } else {
        let fn;
        if(argv.i) {fn =argv.i} else {fn=creat_id()+'.tree'}
        let forest = new Forest(argv.m);
        let rt;
        if(fs.existsSync(fn)) {
             let s = fs.readFileSync(fn).toString();
             let j = JSON.parse(s);
             rt = forest.load_nd_from_dump(Branch,j);
        } else {
             rt = forest.node(Branch);
        }
        console.log(fn+" :");
        console.log('='.repeat(fn.length+2))
        console.log(build(rt,argv.p,argv.n,argv.c,argv.a,argv.b,argv.r))
        let j = rt.$dump();
        fs.writeFileSync(fn,JSON.stringify(j))
    }
}

module.exports = run 

